@@ -11,8 +11,8 @@
 -- (~/.luarocks/config.lua on Unix or %APPDATA%/luarocks/config.lua on
 -- Windows).
 
-local rawset, next, table, pairs, require, io, os, setmetatable, pcall, ipairs, package, type, assert =
-      rawset, next, table, pairs, require, io, os, setmetatable, pcall, ipairs, package, type, assert
+local rawset, next, table, pairs, require, io, os, setmetatable, pcall, ipairs, package, type, assert, _VERSION =
+      rawset, next, table, pairs, require, io, os, setmetatable, pcall, ipairs, package, type, assert, _VERSION
 
 module("luarocks.cfg")
 
@@ -25,6 +25,7 @@ end
 
 _M.site_config = site_config
 
+lua_version = _VERSION:sub(5)
 program_version = "2.0.8"
 user_agent = "LuaRocks/"..program_version
 
@@ -76,6 +77,9 @@ elseif system == "Darwin" then
 elseif system == "Linux" then
    detected.unix = true
    detected.linux = true
+elseif system == "SunOS" then
+   detected.unix = true
+   detected.solaris = true
 elseif system and system:match("^CYGWIN") then
    detected.unix = true
    detected.cygwin = true
@@ -94,12 +98,12 @@ local sys_config_file, home_config_file
 local sys_config_ok, home_config_ok = false, false
 if detected.windows or detected.mingw32 then
    home = os.getenv("APPDATA") or "c:"
-   sys_config_file = "c:/luarocks/config.lua"
+   sys_config_file = site_config.LUAROCKS_SYSCONFIG or "c:/luarocks/config.lua"
    home_config_file = home.."/luarocks/config.lua"
    home_tree = home.."/luarocks/"
 else
    home = os.getenv("HOME") or ""
-   sys_config_file = "/etc/luarocks/config.lua"
+   sys_config_file = site_config.LUAROCKS_SYSCONFIG or "/etc/luarocks/config.lua"
    home_config_file = home.."/.luarocks/config.lua"
    home_tree = home.."/.luarocks/"
 end
@@ -107,11 +111,14 @@ end
 variables = {}
 rocks_trees = {}
 
-local ok, err = persist.load_into_table(site_config.LUAROCKS_SYSCONFIG or sys_config_file, _M)
+local ok, err = persist.load_into_table(sys_config_file, _M)
 if ok then
    sys_config_ok = true
-elseif err and ok == nil then
-   io.stderr:write(err.."\n")
+else -- nil or false
+   sys_config_ok = ok
+   if err and ok == nil then
+      io.stderr:write(err.."\n")
+   end
 end
 
 if not site_config.LUAROCKS_FORCE_CONFIG then
@@ -127,8 +134,11 @@ if not site_config.LUAROCKS_FORCE_CONFIG then
          _M.rocks_servers = nil
       end
       util.deep_merge(_M, home_overrides)
-   elseif err and home_overrides == nil then
-      io.stderr:write(err.."\n")
+   else -- nil or false
+      home_config_ok = home_overrides
+      if err and home_config_ok == nil then
+         io.stderr:write(err.."\n")
+      end
    end
 end
 
@@ -150,8 +160,8 @@ local defaults = {
    use_extensions = false,
    accept_unknown_fields = false,
 
-   lua_modules_path = "/share/lua/5.1/",
-   lib_modules_path = "/lib/lua/5.1/",
+   lua_modules_path = "/share/lua/"..lua_version,
+   lib_modules_path = "/lib/lua/"..lua_version,
 
    arch = "unknown",
    lib_extension = "unknown",
@@ -230,9 +240,9 @@ if detected.windows then
    defaults.external_lib_extension = "dll"
    defaults.obj_extension = "obj"
    defaults.external_deps_dirs = { "c:/external/" }
-   defaults.variables.LUA_BINDIR = site_config.LUA_BINDIR and site_config.LUA_BINDIR:gsub("\\", "/") or "c:/lua5.1/bin"
-   defaults.variables.LUA_INCDIR = site_config.LUA_INCDIR and site_config.LUA_INCDIR:gsub("\\", "/") or "c:/lua5.1/include"
-   defaults.variables.LUA_LIBDIR = site_config.LUA_LIBDIR and site_config.LUA_LIBDIR:gsub("\\", "/") or "c:/lua5.1/lib"
+   defaults.variables.LUA_BINDIR = site_config.LUA_BINDIR and site_config.LUA_BINDIR:gsub("\\", "/") or "c:/lua"..lua_version.."/bin"
+   defaults.variables.LUA_INCDIR = site_config.LUA_INCDIR and site_config.LUA_INCDIR:gsub("\\", "/") or "c:/lua"..lua_version.."/include"
+   defaults.variables.LUA_LIBDIR = site_config.LUA_LIBDIR and site_config.LUA_LIBDIR:gsub("\\", "/") or "c:/lua"..lua_version.."/lib"
    defaults.cmake_generator = "MinGW Makefiles"
    defaults.makefile = "Makefile.win"
    defaults.variables.MAKE = "nmake" -- TODO: Split Windows flavors between mingw and msvc
@@ -241,10 +251,10 @@ if detected.windows then
    defaults.variables.WRAPPER = site_config.LUAROCKS_PREFIX .. "\\2.0\\rclauncher.obj"
    defaults.variables.LD = "link"
    defaults.variables.MT = "mt"
-   defaults.variables.LUALIB = "lua5.1.lib"
+   defaults.variables.LUALIB = "lua"..lua_version..".lib"
    defaults.variables.CFLAGS = "/MD /O2"
    defaults.variables.LIBFLAG = "/dll"
-   defaults.variables.LUALIB = "lua5.1.lib"
+   defaults.variables.LUALIB = "lua"..lua_version..".lib"
    defaults.external_deps_patterns = {
       bin = { "?.exe", "?.bat" },
       lib = { "?.lib", "?.dll", "lib?.dll" },
@@ -268,9 +278,9 @@ if detected.mingw32 then
    defaults.external_lib_extension = "dll"
    defaults.obj_extension = "o"
    defaults.external_deps_dirs = { "c:/external/" }
-   defaults.variables.LUA_BINDIR = site_config.LUA_BINDIR and site_config.LUA_BINDIR:gsub("\\", "/") or "c:/lua5.1/bin"
-   defaults.variables.LUA_INCDIR = site_config.LUA_INCDIR and site_config.LUA_INCDIR:gsub("\\", "/") or "c:/lua5.1/include"
-   defaults.variables.LUA_LIBDIR = site_config.LUA_LIBDIR and site_config.LUA_LIBDIR:gsub("\\", "/") or "c:/lua5.1/lib"
+   defaults.variables.LUA_BINDIR = site_config.LUA_BINDIR and site_config.LUA_BINDIR:gsub("\\", "/") or "c:/lua"..lua_version.."/bin"
+   defaults.variables.LUA_INCDIR = site_config.LUA_INCDIR and site_config.LUA_INCDIR:gsub("\\", "/") or "c:/lua"..lua_version.."/include"
+   defaults.variables.LUA_LIBDIR = site_config.LUA_LIBDIR and site_config.LUA_LIBDIR:gsub("\\", "/") or "c:/lua"..lua_version.."/lib"
    defaults.cmake_generator = "MinGW Makefiles"
    defaults.make = "mingw32-make" -- TODO: Split Windows flavors between mingw and msvc
    defaults.makefile = "Makefile.win"
@@ -335,6 +345,10 @@ if detected.cygwin then
    defaults.variables.LIBFLAG = "-shared"
 end
 
+if detected.bsd then
+   defaults.variables.STATFLAG = "-f '%Op'"
+end
+
 if detected.macosx then
    defaults.external_lib_extension = "dylib"
    defaults.arch = "macosx-"..proc
@@ -342,9 +356,6 @@ if detected.macosx then
    defaults.variables.CC = "export MACOSX_DEPLOYMENT_TARGET=10.3; gcc"
    defaults.variables.LD = "export MACOSX_DEPLOYMENT_TARGET=10.3; gcc"
    defaults.variables.LIBFLAG = "-bundle -undefined dynamic_lookup -all_load"
-end
-
-if detected.bsd then
    defaults.variables.STATFLAG = "-f '%A'"
 end
 
@@ -368,7 +379,14 @@ end
 if detected.openbsd then
    defaults.arch = "openbsd-"..proc
    defaults.platforms = {"unix", "bsd", "openbsd"}
-   defaults.variables.STATFLAG = "-f '%Op'"
+end
+
+if detected.solaris then
+   defaults.arch = "solaris-"..proc
+   defaults.platforms = {"unix", "solaris"}
+   defaults.variables.MAKE = "gmake"
+   defaults.variables.CC = "gcc"
+   defaults.variables.LD = "gcc"
 end
 
 -- Expose some more values detected by LuaRocks for use by rockspec authors.
