@@ -1,8 +1,9 @@
 
+--- Unix implementation of filesystem and platform abstractions.
+
 local assert, type, table, io, package, math, os, ipairs =
       assert, type, table, io, package, math, os, ipairs
 
---- Unix implementation of filesystem and platform abstractions.
 module("luarocks.fs.unix", package.seeall)
 
 local fs = require("luarocks.fs")
@@ -10,6 +11,7 @@ local fs = require("luarocks.fs")
 local cfg = require("luarocks.cfg")
 local dir = require("luarocks.dir")
 local fs = require("luarocks.fs")
+local util = require("luarocks.util")
 
 math.randomseed(os.time())
 
@@ -52,7 +54,7 @@ function wrap_script(file, dest)
    wrapper:write('export LUA_PATH LUA_CPATH\n')
    wrapper:write('exec "'..dir.path(cfg.variables["LUA_BINDIR"], cfg.lua_interpreter)..'" -lluarocks.loader "'..file..'" "$@"\n')
    wrapper:close()
-   if fs.execute("chmod +x",wrapname) then
+   if fs.chmod(wrapname, "0755") then
       return true
    else
       return nil, "Could not make "..wrapname.." executable."
@@ -69,57 +71,18 @@ function is_actual_binary(filename)
       return false
    end
    local file = io.open(filename)
-   if file then
-      local found = false
-      local first = file:read()
-      if first:match("#!.*lua") then
-         found = true
-      elseif first:match("#!/bin/sh") then
-         local line = file:read()
-         line = file:read()
-         if not(line and line:match("LUA_PATH")) then
-            found = true
-         end
-      end
-      file:close()
-      if found then
-         return false
-      else
-         return true
-      end
-   else
+   if not file then
       return true
    end
-   return false
-end
-
-function is_actual_binary(filename)
-   if filename:match("%.lua$") then
-      return false
-   end
-   local file = io.open(filename)
-   if file then
-      local found = false
-      local first = file:read()
-      if first:match("#!.*lua") then
-         file:close()
-         return true
-      elseif first:match("#!/bin/sh") then
-         local line = file:read()
-         line = file:read()
-         if not(line and line:match("LUA_PATH")) then
-            file:close()
-            return true
-         end
-      end
-      file:close()
-   else
+   local first = file:read(2)
+   file:close()
+   if not first then
+      util.printerr("Warning: could not read "..filename)
       return true
    end
-   return false
+   return first ~= "#!"
 end
 
 function copy_binary(filename, dest) 
-   return fs.copy(filename, dest)
+   return fs.copy(filename, dest, "0755")
 end
-
