@@ -15,7 +15,7 @@ local dir = require("luarocks.dir")
 function Q(arg)
    assert(type(arg) == "string")
    -- Quote DIR for Windows
-    if arg:match("^[\.a-zA-Z]?:?[\\/]")  then
+    if arg:match("^[%.a-zA-Z]?:?[\\/]")  then
         return '"' .. arg:gsub("/", "\\"):gsub('"', '\\"') .. '"'
     end
     -- URLs and anything else
@@ -33,7 +33,9 @@ function absolute_name(pathname, relative_to)
    assert(type(relative_to) == "string" or not relative_to)
 
    relative_to = relative_to or fs.current_dir()
-   if pathname:match("^[\.a-zA-Z]?:?[\\/]") then
+   -- FIXME I'm not sure this first \\ should be there at all.
+   -- What are the Windows rules for drive letters?
+   if pathname:match("^[\\.a-zA-Z]?:?[\\/]") then
       return pathname
    else
       return relative_to .. "/" .. pathname
@@ -95,3 +97,11 @@ function copy_binary(filename, dest)
    end
    return true
 end
+
+function chmod(filename, mode)
+   return true
+end
+
+function get_permissions(filename)
+   return ""
+end
