@@ -21,15 +21,15 @@ help = [[
 function run(...)
    local flags, filter, version = util.parse_flags(...)
    local results = {}
-   local query = search.make_query(filter or "", version)
+   local query = search.make_query(filter and filter:lower() or "", version)
    query.exact_name = false
    for _, tree in ipairs(cfg.rocks_trees) do
       search.manifest_search(results, path.rocks_dir(tree), query)
    end
-   print()
-   print("Installed rocks:")
-   print("----------------")
-   print()
+   util.printout()
+   util.printout("Installed rocks:")
+   util.printout("----------------")
+   util.printout()
    search.print_results(results, false)
    return true
 end
