@@ -11,6 +11,7 @@ local cfg = require("luarocks.cfg")
 local util = require("luarocks.util")
 local dir = require("luarocks.dir")
 local manif = require("luarocks.manif")
+local search = require("luarocks.search")
 
 help_summary = "Create a rock, packing sources or binaries."
 help_arguments = "{<rockspec>|<name> [<version>]}"
@@ -31,11 +32,11 @@ argument.
 local function pack_source_rock(rockspec_file)
    assert(type(rockspec_file) == "string")
 
-   rockspec_file = fs.absolute_name(rockspec_file)
    local rockspec, err = fetch.load_rockspec(rockspec_file)
    if err then
       return nil, "Error loading rockspec: "..err
    end
+   rockspec_file = rockspec.local_filename
 
    local name_version = rockspec.name .. "-" .. rockspec.version
    local rock_file = fs.absolute_name(name_version .. ".src.rock")
@@ -79,30 +80,43 @@ end
 -- @param version string or nil: A version number may also be passed.
 -- @return string or (nil, string): The filename of the resulting
 -- .src.rock file; or nil and an error message.
-local function pack_binary_rock(name, version)
+local function do_pack_binary_rock(name, version)
    assert(type(name) == "string")
    assert(type(version) == "string" or not version)
+
+   local query = search.make_query(name, version)
+   query.exact_name = true
+   local results = {}
    
-   local versions = rep.get_versions(name)
+   search.manifest_search(results, cfg.rocks_dir, query)
    
-   if not versions then
+   if not next(results) then
       return nil, "'"..name.."' does not seem to be an installed rock."
    end
+   
+   local versions = results[name]
+   
    if not version then
-      if #versions > 1 then
+      local first = next(versions)
+      if next(versions, first) then
          return nil, "Please specify which version of '"..name.."' to pack."
       end
-      version = versions[1]
+      version = first
    end
    if not version:match("[^-]+%-%d+") then
       return nil, "Expected version "..version.." in version-revision format."
    end
-   local prefix = path.install_dir(name, version)
+   
+   local info = versions[version][1]
+   
+   local root = path.root_dir(info.repo)
+   local prefix = path.install_dir(name, version, root)
+   
    if not fs.exists(prefix) then
       return nil, "'"..name.." "..version.."' does not seem to be an installed rock."
    end
-
-   local rock_manifest = manif.load_rock_manifest(name, version)
+   
+   local rock_manifest = manif.load_rock_manifest(name, version, root)
    if not rock_manifest then
       return nil, "rock_manifest file not found for "..name.." "..version.." - not a LuaRocks 2 tree?"
    end
@@ -115,11 +129,11 @@ local function pack_binary_rock(name, version)
 
    local is_binary = false
    if rock_manifest.lib then
-      copy_back_files(name, version, rock_manifest.lib, cfg.deploy_lib_dir, dir.path(temp_dir, "lib"))
+      copy_back_files(name, version, rock_manifest.lib, path.deploy_lib_dir(root), dir.path(temp_dir, "lib"))
       is_binary = true
    end
    if rock_manifest.lua then
-      copy_back_files(name, version, rock_manifest.lua, cfg.deploy_lua_dir, dir.path(temp_dir, "lua"))
+      copy_back_files(name, version, rock_manifest.lua, path.deploy_lua_dir(root), dir.path(temp_dir, "lua"))
    end
    
    fs.change_dir(temp_dir)
@@ -135,6 +149,33 @@ local function pack_binary_rock(name, version)
    return rock_file
 end
 
+function pack_binary_rock(name, version, cmd, ...)
+
+   -- The --pack-binary-rock option for "luarocks build" basically performs
+   -- "luarocks build" on a temporary tree and then "luarocks pack". The
+   -- alternative would require refactoring parts of luarocks.build and
+   -- luarocks.pack, which would save a few file operations: the idea would be
+   -- to shave off the final deploy steps from the build phase and the initial
+   -- collect steps from the pack phase.
+
+   local temp_dir = fs.make_temp_dir("luarocks-build-pack-"..dir.base_name(name))
+   if not temp_dir then
+      return nil, "Failed creating temporary directory."
+   end
+   util.schedule_function(fs.delete, temp_dir)
+
+   path.use_tree(temp_dir)
+   local ok, err = cmd(...)
+   if not ok then
+      return nil, err
+   end
+   local rname, rversion = path.parse_name(name)
+   if not rname then
+      rname, rversion = name, version
+   end
+   return do_pack_binary_rock(rname, rversion)
+end
+
 --- Driver function for the "pack" command.
 -- @param arg string:  may be a rockspec file, for creating a source rock,
 -- or the name of an installed package, for creating a binary rock.
@@ -149,9 +190,16 @@ function run(...)
       return nil, "Argument missing, see help."
    end
 
+   local file, err
    if arg:match(".*%.rockspec") then
-      return pack_source_rock(arg)
+      file, err = pack_source_rock(arg)
    else
-      return pack_binary_rock(arg, version)
+      file, err = do_pack_binary_rock(arg, version)
+   end
+   if err then
+      return nil, err
+   else
+      util.printout("Packed: "..file)
+      return true
    end
 end
