@@ -1,4 +1,5 @@
 
+--- Module implementing the luarocks-admin "refresh_cache" command.
 module("luarocks.refresh_cache", package.seeall)
 
 local util = require("luarocks.util")
@@ -15,15 +16,11 @@ from the configuration file is used instead.
 
 function run(...)
    local flags = util.parse_flags(...)
-   local server = flags["from"]
-   if not server then server = cfg.upload_server end
-   if not server then
-      return nil, "No server specified with --from and no default configured with upload_server."
-   end
-   if cfg.upload_servers and cfg.upload_servers[server] and cfg.upload_servers[server].http then
-      server = "http://"..cfg.upload_servers[server].http
-   end
-   local ok, err = cache.refresh_local_cache(server, cfg.upload_user, cfg.upload_password)
+   local server, upload_server = cache.get_upload_server(flags["server"])
+   if not server then return nil, upload_server end
+   local download_url = cache.get_server_urls(server, upload_server)
+   
+   local ok, err = cache.refresh_local_cache(server, download_url, cfg.upload_user, cfg.upload_password)
    if not ok then
       return nil, err
    else
