@@ -153,7 +153,7 @@ function run_hook(rockspec, hook_name)
    end
    local hook = hooks[hook_name]
    if hook then
-      print(hook)
+      util.printout(hook)
       if not fs.execute(hook) then
          return nil, "Failed running "..hook_name.." hook."
       end
@@ -194,9 +194,22 @@ local function resolve_conflict(target, deploy_dir, name, version)
    end
 end
 
-function deploy_files(name, version)
+function should_wrap_bin_scripts(rockspec)
+   assert(type(rockspec) == "table")
+
+   if cfg.wrap_bin_scripts ~= nil then
+      return cfg.wrap_bin_scripts
+   end
+   if rockspec.deploy and rockspec.deploy.wrap_bin_scripts == false then
+      return false
+   end
+   return true
+end
+
+function deploy_files(name, version, wrap_bin_scripts)
    assert(type(name) == "string")
    assert(type(version) == "string")
+   assert(type(wrap_bin_scripts) == "boolean")
 
    local function deploy_file_tree(file_tree, source_dir, deploy_dir, move_fn)
       if not move_fn then
@@ -209,10 +222,13 @@ function deploy_files(name, version)
             local ok, err
             if fs.exists(target) then
                local new_target, err = resolve_conflict(target, deploy_dir, name, version)
-	       if err == "untracked" then
-		 fs.delete(target)
-	       elseif err then return nil, err.." Cannot install new version."
-	       else target = new_target end
+               if err == "untracked" then
+                  fs.delete(target)
+               elseif err then
+                  return nil, err.." Cannot install new version."
+               else
+                  target = new_target
+               end
 	    end
             fs.make_dir(dir.dir_name(target))
             ok, err = move_fn(source, target)
@@ -227,7 +243,8 @@ function deploy_files(name, version)
    
    local ok, err = true
    if rock_manifest.bin then
-      ok, err = deploy_file_tree(rock_manifest.bin, path.bin_dir(name, version), cfg.deploy_bin_dir, install_binary)
+      local move_bin_fn = wrap_bin_scripts and install_binary or fs.copy_binary
+      ok, err = deploy_file_tree(rock_manifest.bin, path.bin_dir(name, version), cfg.deploy_bin_dir, move_bin_fn)
    end
    if ok and rock_manifest.lua then
       ok, err = deploy_file_tree(rock_manifest.lua, path.lua_dir(name, version), cfg.deploy_lua_dir)
@@ -252,10 +269,11 @@ function delete_version(name, version)
             local target = dir.path(deploy_dir, parent_path, file)
             local versioned = path.versioned_name(target, deploy_dir, name, version)
             if fs.exists(versioned) then
-               fs.delete(versioned)
+               local ok = fs.delete(versioned)
                fs.remove_dir_tree_if_empty(dir.dir_name(versioned))
+               if not ok then return nil, "Failed deleting "..versioned end
             else
-               fs.delete(target)
+               local ok = fs.delete(target)
                local next_name, next_version = manif.find_next_provider(target)
                if next_name then
                   local versioned = path.versioned_name(target, deploy_dir, next_name, next_version)
@@ -263,6 +281,7 @@ function delete_version(name, version)
                   fs.remove_dir_tree_if_empty(dir.dir_name(versioned))
                end
                fs.remove_dir_tree_if_empty(dir.dir_name(target))
+               if not ok then return nil, "Failed deleting "..target end
             end
             return true
          end
