@@ -334,7 +334,7 @@ end
 -- @param name string: A rock name
 -- @param version string or nil: A version number may also be given.
 -- @return The result of the action function, or nil and an error message. 
-function act_on_src_or_rockspec(action, name, version)
+function act_on_src_or_rockspec(action, name, version, ...)
    assert(type(action) == "function")
    assert(type(name) == "string")
    assert(type(version) == "string" or not version)
@@ -343,7 +343,7 @@ function act_on_src_or_rockspec(action, name, version)
    query.arch = "src|rockspec"
    local results, err = find_suitable_rock(query)
    if type(results) == "string" then
-      return action(results)
+      return action(results, ...)
    elseif type(results) == "table" and next(results) then
       util.printout("Multiple search results were returned.")
       util.printout()
