@@ -4,12 +4,14 @@
 -- loaded by LuaRocks.
 module("luarocks.type_check", package.seeall)
 
+local cfg = require("luarocks.cfg")
+
 rockspec_format = "1.0"
 
 rockspec_types = {
    rockspec_format = "string",
    MUST_package = "string",
-   MUST_version = "string",
+   MUST_version = "[%w.]+-[%d]+",
    description = {
       summary = "string",
       detailed = "string",
@@ -72,6 +74,17 @@ rockspec_types = {
    }
 }
 
+function load_extensions()
+   rockspec_format = "1.1"
+   rockspec_types.deploy = {
+      wrap_bin_scripts = true,
+   }
+end
+
+if cfg.use_extensions then
+   load_extensions()
+end
+
 rockspec_types.build.platforms.ANY = rockspec_types.build
 rockspec_types.dependencies.platforms.ANY = rockspec_types.dependencies
 rockspec_types.external_dependencies.platforms.ANY = rockspec_types.external_dependencies
@@ -143,6 +156,9 @@ local type_check_table
 -- @param item any: The object being checked.
 -- @param expected any: The reference object. In case of a table,
 -- its is structured as a type reference table.
+-- @param context string: A string indicating the "context" where the
+-- error occurred (such as the name of the table the item is a part of),
+-- to be used by error messages.
 -- @return boolean or (nil, string): true if type checking
 -- succeeded, or nil and an error message if it failed.
 -- @see type_check_table
@@ -155,6 +171,15 @@ local function type_check_item(name, item, expected, context)
       if not tonumber(item) then
          return nil, "Type mismatch on field "..context..name..": expected a number"
       end
+   elseif expected_type == "string" then
+      if not tostring(item) then
+         return nil, "Type mismatch on field "..context..name..": expected a value convertible to string"
+      end
+      if expected ~= "string" then
+         if not item:match("^"..expected.."$") then
+            return nil, "Type mismatch on field "..context..name..": invalid value "..item
+         end
+      end
    elseif expected_type == "table" then
       if item_type ~= expected_type then
          return nil, "Type mismatch on field "..context..name..": expected a table"
@@ -183,6 +208,9 @@ end
 -- @param tbl table: The table to be type checked.
 -- @param types table: The reference table, containing
 -- values for recognized fields in the checked table.
+-- @param context string: A string indicating the "context" where the
+-- error occurred (such as the name of the table the item is a part of),
+-- to be used by error messages.
 -- @return boolean or (nil, string): true if type checking
 -- succeeded, or nil and an error message if it failed.
 type_check_table = function(tbl, types, context)
@@ -196,7 +224,9 @@ type_check_table = function(tbl, types, context)
       elseif types.MORE then
          -- Accept unknown field
       else
-         return nil, "Unknown field "..k
+         if not cfg.accept_unknown_fields then
+            return nil, "Unknown field "..k
+         end
       end
    end
    for k, v in pairs(types) do
@@ -218,6 +248,10 @@ end
 -- succeeded, or nil and an error message if it failed.
 function type_check_rockspec(rockspec)
    assert(type(rockspec) == "table")
+   if rockspec.rockspec_format then
+      -- relies on global state
+      load_extensions()
+   end
    return type_check_table(rockspec, rockspec_types, "")
 end
 
